# behave-db
BDD DB steps implementation for Behave

_behave-db_ is a db testing tools for
Behavior-Driven-Development, based on
[behave](http://pypi.python.org/pypi/behave) and
[JayDeBeApi](https://github.com/baztian/jaydebeapi).


## Hello world (TODO)


